Page 60 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 60

Home

    France.

    Louis XVIII was recalled and served nine years until
    his death. His was the only government that did not come
    to a violent end during the eighty year period. The reign
    of Charles X that followed was overthrown in 1830 by

    an uprising of the Orleanists that placed Louis Philippe
    on the throne, only to be driven out after eighteen years
    of unrest. In this third revolution of 1848, a Second

    Republic was proclaimed.
    Nesta Webster summed up the whole affair in this

    Manner:

    The immense reforms brought about during the
    revolutionary era were not the result of the Revolution. It
    was to the King and his enlightened advisors . . . that the

    "4 1

    reforms in government were primarily due; it was the
    noblesse that dealt the death-blow to the feudal system; it
    was the Royalist Democrats, abhorred of the

    the

    was the Royalist Democrats, abhorred of the
    revolutionary leaders, who drew up the Declaration of
    the Rights of Man and framed the Constitution. The
    work of the Revolution was to destroy all three reforms

    wow woo coat woo. c

    was

    — to abolish the liberty of the press, liberty of
    conscience, personal liberty, to replace the comparatively
    mild feudalism of the Old Regime by the most frightful
    tyranny the world has ever seen, and finally to annul the
    Constitution demanded by the people in favor of a
    Constitution that could never be enforced, that lasted
    exactly twenty-six months, and was followed by no less
    than six others in the eighty years that followed."

    55

    The French Revolution

    defeated at Waterloo, and again foreign armies entered

    Democrats,